tpDcc-libs-qt
============================================================

Collection of Python utilities modules to work with PySide/PyQt and DCCs

.. image:: https://travis-ci.com/tpDcc/tpDcc-libs-qt.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpDcc/tpDcc-libs-qt

.. image:: https://coveralls.io/repos/github/tpDcc/tpDcc-libs-qt/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpDcc/tpDcc-libs-qt?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpDcc.github.io/tpDcc-libs-qt

.. image:: https://img.shields.io/github/license/tpDcc/tpDcc-libs-qt
    :target: https://github.com/tpDcc/tpDcc-libs-qt/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpDcc-libs-qt?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpDcc-libs-qt

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/